==> netcdf-4.6.2-3-src.tar.bz2: osgeo4w/package.sh <==
export P=netcdf
export V=4.6.2
export B=3
export MAINTAINER=JuergenFischer

savelog() {
	local f=$1
	rm -f $f.9
	for i in $(seq 8 -1 0); do [ -f "$f.$i" ] && mv $f.$i $f.$(( i + 1 )); done
	[ -f $f ] && mv $f $f.0
}

savelog package.log
exec > >(tee package.log) 2>&1
date

set -e


[ -f $P-c-$V.tar.gz ] || wget https://www.unidata.ucar.edu/downloads/netcdf/ftp/$P-c-$V.tar.gz
[ -f ../CMakeLists.txt ] || tar -C .. --xform s,$P-c-$V/,, -xzf $P-c-$V.tar.gz
[ -f patched ] || patch -p0 -d .. <patch >patched

if ! [ -d "$OSGEO4W_REP" ]; then
        echo no repository
        exit 1
fi

fetchenv() {
        local IFS
        IFS=
        batch=$1
        shift

        if ! [ -f "$batch" ]; then
                echo "$batch not found"
                return 1
        fi

        srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
        dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
        diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
        envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
        cmd /c set >$srcenv
        cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
        /usr/bin/cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
        s/\\\\/\\//g;
        s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
        s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
        /usr/bin/diff -u $srcenv $dstenv | /usr/bin/sed -f $envdiff >$diffenv
        . $diffenv
        PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
        rm -f $srcenv $dstenv $diffenv $envdiff
}

for ARCH in ${ARCHS:-x86 x86_64}; do
	export ARCH

	(
		case "$ARCH" in
		x86)
			export OSGEO4W_ROOT=/c/OSGeo4W
			export CMAKE_GEN="Visual Studio 14 2015"
			export VCARCH=x86
			export ZLIB=zlib.lib
			;;

		x86_64)
			export OSGEO4W_ROOT=/c/OSGeo4W64
			export VCARCH=x64
			export CMAKE_GEN="Visual Studio 14 2015 Win64"
			export ZLIB=zdll.lib
			;;

		*)
			echo "Unsupported arch $ARCH" >&2
			exit 1
			;;
		esac

		export R=$OSGEO4W_REP/$ARCH/release/$P
		mkdir -p $R

		cat <<EOF >$R/setup.hint
sdesc: "The NetCDF library and commands for reading and writing NetCDF format"
ldesc: "The NetCDF library and commands for reading and writing NetCDF format"
maintainer: $MAINTAINER
category: Libs Commandline_Utilities
requires: msvcrt2015 hdf5 curl zlib
EOF

		cp ../COPYRIGHT $R/$P-$V-$B.txt

		fetchenv $OSGEO4W_ROOT/bin/o4w_env.bat
		fetchenv "/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/vcvarsall.bat" $VCARCH

		export PATH="/c/Program Files (x86)/Microsoft Visual Studio 14.0/Common7/IDE:/c/Program Files/CMake/bin:/bin:/usr/bin:$PATH"
		export INSTDIR=$PWD/install-$ARCH

		rm -rf $INSTDIR
		mkdir -p build-$ARCH $INSTDIR
		cd build-$ARCH

		cmake -G "$CMAKE_GEN" \
			-D CMAKE_INSTALL_PREFIX=../install-$ARCH \
			-D CMAKE_MODULE_PATH="${CMAKE_ROOT}/cmake/modules/ ${CMAKE_SOURCE_DIR}/cmake/modules/ ${CMAKE_SOURCE_DIR}/cmake/modules/windows" \
			-D HDF5_DIR=$(cygpath -aw $OSGEO4W_ROOT/share/cmake/hdf5) \
			-D HDF5_INCLUDE_DIR=$(cygpath -aw $OSGEO4W_ROOT/include) \
			-D CURL_INCLUDE_DIR=$(cygpath -aw $OSGEO4W_ROOT/include) \
			-D CURL_LIBRARY=$(cygpath -aw $OSGEO4W_ROOT/lib/libcurl.lib) \
			-D ZLIB_INCLUDE_DIR=$(cygpath -aw $OSGEO4W_ROOT/include) \
			-D ZLIB_LIBRARY=$(cygpath -aw $OSGEO4W_ROOT/lib/$ZLIB) \
			../..

		cmake --build . --config RelWithDebInfo
		cmake --build . --config RelWithDebInfo --target INSTALL

		/bin/tar -C $INSTDIR -cjf $R/$P-$V-$B.tar.bz2 \
			bin include lib
		
		/bin/tar -C ../.. -cjf $R/$P-$V-$B-src.tar.bz2 \
			osgeo4w/package.sh osgeo4w/patch
	)
done

==> netcdf-4.7.3-2-src.tar.bz2: osgeo4w/package.sh <==
export P=netcdf
export V=4.7.3
export B=2
export MAINTAINER=JuergenFischer

savelog() {
	local f=$1
	rm -f $f.9
	for i in $(seq 8 -1 0); do [ -f "$f.$i" ] && mv $f.$i $f.$(( i + 1 )); done
	[ -f $f ] && mv $f $f.0
}

savelog package.log
exec > >(tee package.log) 2>&1
date

set -e

[ -f $P-c-$V.tar.gz ] || wget ftp://ftp.unidata.ucar.edu/pub/$P/$P-c-$V.tar.gz
[ -f ../CMakeLists.txt ] || tar -C .. --xform s,$P-c-$V/,, -xzf $P-c-$V.tar.gz
[ -f patched ] || patch -p0 -d .. <patch >patched

if ! [ -d "$OSGEO4W_REP" ]; then
        echo no repository
        exit 1
fi

fetchenv() {
        local IFS
        IFS=
        batch=$1
        shift

        if ! [ -f "$batch" ]; then
                echo "$batch not found"
                return 1
        fi

        srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
        dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
        diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
        envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
        cmd /c set >$srcenv
        cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
        /usr/bin/cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
        s/\\\\/\\//g;
        s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
        s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
        /usr/bin/diff -u $srcenv $dstenv | /usr/bin/sed -f $envdiff >$diffenv
        . $diffenv
        PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
        rm -f $srcenv $dstenv $diffenv $envdiff
}

for ARCH in ${ARCHS:-x86 x86_64}; do
	export ARCH

	(
		case "$ARCH" in
		x86)
			export OSGEO4W_ROOT=/c/OSGeo4W
			export CMAKE_GEN="Visual Studio 14 2015"
			export VCARCH=x86
			export ZLIB=zlib.lib
			;;

		x86_64)
			export OSGEO4W_ROOT=/c/OSGeo4W64
			export VCARCH=x64
			export CMAKE_GEN="Visual Studio 14 2015 Win64"
			export ZLIB=zdll.lib
			;;

		*)
			echo "Unsupported arch $ARCH" >&2
			exit 1
			;;
		esac

		export R=$OSGEO4W_REP/$ARCH/release/$P
		mkdir -p $R

		cat <<EOF >$R/setup.hint
sdesc: "The NetCDF library and commands for reading and writing NetCDF format"
ldesc: "The NetCDF library and commands for reading and writing NetCDF format"
category: Libs Commandline_Utilities
requires: hdf5 curl
EOF

		cp ../COPYRIGHT $R/$P-$V-$B.txt

		fetchenv $OSGEO4W_ROOT/bin/o4w_env.bat
		fetchenv "/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/vcvarsall.bat" $VCARCH

		export PATH="/c/Program Files (x86)/Microsoft Visual Studio 14.0/Common7/IDE:/c/Program Files/CMake/bin:$PATH:/bin"
		export INSTDIR=$PWD/install-$ARCH
		export BUILDCONF=Release

		rm -rf $INSTDIR

		mkdir -p build-$ARCH
		cd build-$ARCH

		cmake -G "$CMAKE_GEN" \
			-D CMAKE_INSTALL_PREFIX=$(cygpath -aw $INSTDIR) \
			-D CMAKE_MODULE_PATH='${CMAKE_ROOT}/cmake/modules/ ${CMAKE_SOURCE_DIR}/cmake/modules/ ${CMAKE_SOURCE_DIR}/cmake/modules/windows' \
			-D HDF5_DIR=$(cygpath -aw $OSGEO4W_ROOT/share/cmake/hdf5) \
			-D CURL_INCLUDE_DIR=$(cygpath -aw $OSGEO4W_ROOT/include) \
			-D CURL_LIBRARY=$(cygpath -aw $OSGEO4W_ROOT/lib/libcurl.lib) \
			-D ZLIB_INCLUDE_DIR=$(cygpath -aw $OSGEO4W_ROOT/include) \
			-D ZLIB_LIBRARY=$(cygpath -aw $OSGEO4W_ROOT/lib/$ZLIB) \
			-D ENABLE_HDF4=OFF \
			../..

		for i in ZERO_CHECK ALL_BUILD INSTALL; do
			echo "$i: $(date)"
			cmake --build . --target $i --config $BUILDCONF
		done

		/bin/sed -e "s#$(cygpath -am $INSTDIR)#@osgeo4w_msys@#" $INSTDIR/bin/nc-config >$INSTDIR/bin/nc-config.tmpl

		/bin/mkdir -p $INSTDIR/etc/postinstall $INSTDIR/etc/preremove
		/bin/cat >$INSTDIR/etc/postinstall/$P.bat <<EOF
textreplace -std -t "%OSGEO4W_ROOT%"\\bin\\nc-config
EOF
		/bin/cat >$INSTDIR/etc/preremove/$P.bat <<EOF
del "%OSGEO4W_ROOT%\\bin\\nc-config"
EOF

		/bin/tar -C $INSTDIR -cjf $R/$P-$V-$B.tar.bz2 \
			--exclude bin/concrt140.dll \
			--exclude bin/msvcp140.dll \
			--exclude bin/vcruntime140.dll \
			--exclude bin/nc-config \
			bin include lib etc

		/bin/tar -C ../.. -cjf $R/$P-$V-$B-src.tar.bz2 \
			osgeo4w/package.sh osgeo4w/patch
	)
done
